KitBottomSheet class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

actions<T>(List<KitSheetAction<T>> actions, {String? title}) Future<T?>
A ready-made action list, e.g. for a "share/edit/delete" menu.
show<T>(Widget child, {bool isScrollControlled = true, bool useSafeArea = true, double borderRadius = 20}) Future<T?>