KitPermission class

Thin, testable wrapper around permission_handler returning a KitResult instead of throwing, plus a couple of ergonomic helpers (requestAll, openSettingsIfPermanentlyDenied).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

openAppSettings() Future<bool>
request(KitPermissionType type) Future<KitResult<KitPermissionStatus>>
requestAll(List<KitPermissionType> types) Future<Map<KitPermissionType, KitPermissionStatus>>
Requests several permissions and reports which ones were granted.
status(KitPermissionType type) Future<KitPermissionStatus>