KitStorage class

Unified storage facade:

  • KitStorage.plain for non-sensitive key/value data (SharedPreferences).
  • KitStorage.secure for tokens, credentials, anything sensitive (Keychain on iOS, EncryptedSharedPreferences on Android).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearAll() Future<bool>
clearSecure() Future<void>
getBool(String key) bool?
getInt(String key) int?
getJson(String key) Map<String, dynamic>?
getSecure(String key) Future<String?>
getString(String key) String?
init() Future<void>
remove(String key) Future<bool>
removeSecure(String key) Future<void>
setBool(String key, bool value) Future<bool>
setInt(String key, int value) Future<bool>
setJson(String key, Map<String, dynamic> value) Future<bool>
setSecure(String key, String value) Future<void>
setString(String key, String value) Future<bool>