KitImagePicker class
Image and video selection wrapped around image_picker.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
pickImage(
{KitImageSource source = KitImageSource.gallery, int imageQuality = 85, double? maxWidth, double? maxHeight}) → Future< KitResult< File> > -
pickMultipleImages(
{int imageQuality = 85, int? limit}) → Future< KitResult< List< >File> > -
pickVideo(
{KitImageSource source = KitImageSource.gallery, Duration? maxDuration}) → Future< KitResult< File> >